MEWSDocumentListOutlineController = new Class({

    Extends: WBLOutlineController,

    initialize: function(outlineElement, options){
        if(options){
            options.adjustColumnWidths = true;
            options.complexColumnWidthComputation = true;
        }
        this.parent(outlineElement, options)
    },

    setupAfterContentDocumentIsReady: function(){
        this.prepareForResize();
        this.parent();

        // Adjust the background color which is normally fetched from the parent document
        this.table.getParent(this.iFrame ? 'html' : '.main.content.background').setStyle('background-color','#E6E6E6');        
    },

    setOpenButton: function(button){
        this.openButton = button;
        this.updateOpenButtonEnabledState();
        var me = this;
        this.openButton.addEvent('click', function(event){
            me.openSelectedDocument.call(me, event);
        });
        this.updateLayout();
    },

    isAnyDocumentSelected: function(){
        return this.selectedRows && this.selectedRows.length > 0;
    },

    updateOpenButtonEnabledState: function(){
        if(this.openButton){            
            if(this.isAnyDocumentSelected())
                this.openButton.removeClass('disabled');
            else
                this.openButton.addClass('disabled');
        }
    },
    
    dispose: function(){
        this.parent();
    },

    isMetaKeyPressed: function(event){
        return event.meta;
    },
    
    doubleClick: function(row, event){
        this.askServerToOpenProjectForRow(row, this.isMetaKeyPressed(event));
    },

    enterKeyPressed: function(event){
        this.openSelectedDocument(event);
    },

    openSelectedDocument: function(event){
        if(this.isAnyDocumentSelected()){
            this.askServerToOpenProjectForRow(this.selectedRows[0], this.isMetaKeyPressed(event));
        }
    },

    documentURLForRow: function(row){
        var property = 'data-document-path';
        var element = row.getElement('['+property+']');
        var path = element ? element.getProperty(property) : null;
        if(!path)
            return null;
        var URL = window.location.protocol + '//' + window.location.host+'/';
        URL += path+"?listSessionID="+this.options.sessionID;
        return URL;
    },

    // Ask the server to open a project for the given row.
    askServerToOpenProjectForRow: function(row, inOwnWindow){
        var documentURLForRow = this.documentURLForRow(row);
        if(documentURLForRow)
        {
            if(inOwnWindow)
                window.open(documentURLForRow, '_blank');
            else
                window.location = documentURLForRow;
        }
    },
    
    askServerToOpenProjectForRowAtIndex: function(rowIndex, inOwnWindow){
        this.askServerToOpenProjectForRow(this.rowAtIndex(rowIndex), inOwnWindow);
    },
    
    updateSelectionBorders: function(){
        // We do not show selection borders in this outline, so we do not call the super method.
        this.updateOpenButtonEnabledState();
    },
        
    // We need to adjust the size of the outline container manually because
    // an iFrame might be used which can not be influenced by its content.
    prepareForResize: function(){
        this.outlineContainer = $('outlineContainer');
        this.ocOriginalBottom = this.outlineContainer.getStyle('bottom').toInt();
        this.ocTop = this.outlineContainer.getStyle('top').toInt();
        this.ocTitleHeight = $('titleHeader').getStyle('height').toInt();
    },

    // See prepareForResize
    updateLayout: function () {
        var footer = $('footer');
        if(this.table && footer){
            var outlineHeight = this.table.getSize().y;
            var oc = this.outlineContainer;
            var origBottom = this.ocOriginalBottom;
            var winHeight = window.getSize().y;
            var ocFooterHeight = footer.getStyle('height').toInt();
            var availableHeight = winHeight-this.ocTop-origBottom-this.ocTitleHeight-ocFooterHeight;
            var newBottom;
            if(outlineHeight >= availableHeight)
                newBottom = origBottom;
            else
                newBottom = (origBottom+availableHeight-outlineHeight);
            oc.setStyle('bottom', ''+newBottom+'px');
            
            if(this.openButton){
                var pos  = oc.getPosition();
                var size = oc.getSize();
                pos.y += size.y+15;
                pos.x += Math.fround(size.x - this.openButton.getSize().x);
                this.openButton.setStyle('top', pos.y+'px');
                this.openButton.setStyle('left', pos.x+'px');
            }
        }
        this.parent();
    }
    
    
    
});